Attribute VB_Name = "Program"
' Copyright (c) Traeger Industry Components GmbH.  All Rights Reserved.
Option Explicit

'
' This sample demonstrates how to work with the different device types supported by the
' framework.
'
Public Sub Main()
    ''' ================================================================================
    ''' Overall there is not really any special knowledge required to establish a
    ''' connection to a different Simatic device type. As you will see in the following
    ''' snippets there does only differ one argument when initializing a new device
    ''' instance or a single property set call to change the device type.
    ''' ================================================================================
    
    ' 1. Way: Default device type
    ''' The simplest and the most general way is to just initialize a device using the
    ''' constructor accepting the end point information. Using this constructor will
    ''' result into a device object which can be used to access S7-300 and S7-400 PLC
    ''' devices.
    
    Dim device As SimaticDevice
    Set device = New_SimaticDevice(New_IPDeviceEndPoint("192.168.0.80"))
    
    Debug.Print "Default Device.Type=" & device.Type
    
    
    ' 2. Way: Explicit device type
    ''' The advanced way would be to initialize a new device object using the
    ''' constructor which besides of an end point does also accept device type
    ''' information.
    
    Dim deviceLogo As SimaticDevice
    Set deviceLogo = New_SimaticDevice( _
            New_IPDeviceEndPoint("192.168.0.80"), SimaticDeviceType_Logo)
    
    Debug.Print "Explicit Device1.Type=" & deviceLogo.Type
    
    Dim deviceS7300_400 As SimaticDevice
    Set deviceS7300_400 = New_SimaticDevice( _
            New_IPDeviceEndPoint("192.168.0.80"), SimaticDeviceType_S7300_400)
    
    Debug.Print "Explicit Device2.Type=" & deviceS7300_400.Type
    
    Dim deviceS71200 As SimaticDevice
    Set deviceS71200 = New_SimaticDevice( _
            New_IPDeviceEndPoint("192.168.0.80"), SimaticDeviceType_S71200)
    
    Debug.Print "Explicit Device3.Type=" & deviceS71200.Type
    
    Dim deviceS71500 As SimaticDevice
    Set deviceS71500 = New_SimaticDevice( _
            New_IPDeviceEndPoint("192.168.0.80"), SimaticDeviceType_S71500)
    
    Debug.Print "Explicit Device4.Type=" & deviceS71500.Type
    
    
    ' 3. Way: Late device type (re-)definition
    ''' Independent from the way how you decide to initialize your device object you
    ''' are always able to change the device type at runtime.
    
    Dim device1 As SimaticDevice
    Set device1 = New_SimaticDevice( _
            New_IPDeviceEndPoint("192.168.0.80"))

    device1.Type = SimaticDeviceType_S71500
    Debug.Print "Late Device1.Type=" & device1.Type

    Dim device2 As SimaticDevice
    Set device2 = New_SimaticDevice( _
            New_IPDeviceEndPoint("192.168.0.80"), SimaticDeviceType_S71500)

    device2.Type = SimaticDeviceType_S7300_400
    Debug.Print "Late Device2.Type=" & device2.Type
End Sub

